<?php

/*
This class reads the sets of a certain user,
creates directories named like these sets
and starts photo processing

Functions:
- makeDirectory (with Exception-Handling)
- makeDirectories
- processSets
*/

class FlickrMovr {

	private $flickrXML=null;
	

	/*
	Constructor
	*/

	public function __construct() {

		/*
		pre-conditions
		*/

		Utils::cURLcheckBasicFunctions();
		Utils::load_config();
		Utils::check_api_vars();

		/*
		retrieve nsid
		if not previously defined
		*/

		if (!defined('NSID'))
			if (!Utils::query_nsid())
				throw new Exception('User-Name does not exist');

		/*
		create necessary directories
		*/

		$this->makeDirectories();
	
		/*
		authenticate for private photos
		*/

		if (READ_PRIVATE_PHOTOS)
			if (!Utils::authorize_private())
				throw new Exception('Authorization failed!');

		/*
		create instance XML database
		*/

		if (CREATE_XML)
			$this->setFlickrXML(new FlickrMovrDOMDocument(FLICKR_XML));

		/*
		start processing of flickr photos
		*/

		$this->processSets();

	}

	/*
	setters and getters
	*/

	private function setFlickrXML($flickrXML) {
		$this->flickrXML=$flickrXML;
	}

	private function getFlickrXML() {
		return $this->flickrXML;
	}

	/*
	creates necessary directory
	throws exception on error as
	this directory is necessary
	for flickrmovr
	*/

	private function makeDirectory($directory, $type) {
		if (!file_exists($directory))
			if(!@mkdir($directory))
				throw new Exception('Failed to create '.$type.' directory '.$directory);
	}

	/*
	creates PHOTO_DIR and THUMBNAILS_DIR
	*/

	private function makeDirectories() {
		$this->makeDirectory(PHOTO_DIR, 'photo');

		if (DOWNLOAD_THUMBNAILS) {
			$thumbnailsDirectory=PHOTO_DIR.THUMBNAILS_DIR;
			$this->makeDirectory($thumbnailsDirectory, 'thumbnails');
		}
	}

	/*
	initiates the sets' processing
	*/

	private function processSets() {
		Utils::echo_log('Query flickr for user\'s sets');

		$rsp_obj=Utils::query_flickr_api('flickr.photosets.getList', 'user_id', NSID);

		if ($rsp_obj){

			/*
			process all retrieved sets
			*/

			foreach($rsp_obj['photosets']['photoset'] as $photoset) {
				$flickrmovrSet=new FlickrMovrSet($this->getFlickrXML(), $photoset);

			}

			/*
			write current timestamp when finished
			*/

			if (CREATE_XML)
				$this->getFlickrXML()->updateLastDownloadFinished();

			Utils::echo_log('Finished! :)');

		}

		else
			Utils::echo_log('Failed flickr query', -1);

		/*
		delete temp-file
		*/

		if (file_exists(TEMP_DOWNLOAD_FILE))
			@unlink(TEMP_DOWNLOAD_FILE);

	}

}
