<?php

/*
FlickrMovr's Config File

(the location of this file
can be handed over to
the script via a
command-line argument)
*/

/*
Get your free API key on flickr:
https://flickr.com/services/api/keys/
*/

define('API_KEY', '');
define('API_KEY_SECRET', '');

/*
is set to true
FlickrMovr will authorize the API key
for access to all of your photos
(public, friends, family, private)

the oauth-library by David Wilkinson (dopiaza)
used for authentication
is included in this package
and also available here https://github.com/dopiaza/DPZFlickr

please note that this lib needs
at minimum PHP 5.3
*/

define('READ_PRIVATE_PHOTOS', false);

/*
your flickr user-name
*/

define('FLICKR_USER_NAME', '');

/*
PHOTO_DIR is the root directory
in which all sets/thumbnails-directories
and the XML database will be created

has to end with the OS specific
DIRECTORY_SEPARATOR

(e.g. forward-slash in Linux and
back-slash in Windows)
*/

define('PHOTO_DIR', 'photo_dir/');

/*
individual maximal path length of set directories
sets with a name larger than MAX_PATH_LENGTH
will be automatically shortened
*/

define('MAX_PATH_LENGTH', 50);

/*
is set to true
FlickrMovr will download the largest available
version of your photos to the PHOTO_DIR
directory

"Original" > "Large" > "Medium" > "Small" > "Thumbnail" > "Square"
*/

define('DOWNLOAD_PHOTOS', true);

/*
if set to true
FlickrMovr will download the thumbnails (square)
of your photos to the PHOTO_DIR directory
*/

define('DOWNLOAD_THUMBNAILS', true);

/*
this is the name of the sub-directory
for the thumbnails which will be created
within each set's directory
*/

define('THUMBNAILS_DIR', 'thumbnails');

/*
here you can define where FlickrMovr will
download temporary files
*/

define('TEMP_DOWNLOAD_FILE', PHOTO_DIR.'temp.jpg');

/*
if set to true
FlickrMovr processes only new or
modified photos

as the comparison of the timestamps
on flickr and in the XML database is
conducted for each photo individually
this option works only if
CREATE_XML has been set to true

remark: existing files will not be
downloaded or overwritten even if
INCREMENTAL_BACKUP has been set to false
*/

define('INCREMENTAL_BACKUP', true);

/*
if set to true
FlickrMovr creates an "XML database"
with the meta-data of sets and photos

this database can be used to
(i) store your photos'
meta-data and
(ii) as a navigation if you copy
the XSLT stylesheet 'flickrmovr.xsl'
to your PHOTO_DIR
*/

define('CREATE_XML', true);

/*
the directory and filename of your
"XML database"
*/

define('FLICKR_XML', PHOTO_DIR.'photos.xml');

/*
if set to true
FlickrMovr uses ExifTool written by Phil Harvey
to append the meta-tags
(e.g. photo's title, location, ...)
to the JPEG's EXIF tags
http://www.sno.phy.queensu.ca/~phil/exiftool/

to activate download and copy
the exiftool binary file to PHOTO_DIR
*/

define('STORE_META_DATA_IN_EXIF', false);

/*
if set to true
FlickrMovr uses ExifTool
to change the file date to the creation date

STORE_META_DATA_IN_EXIF needs to be
set to true to make this work
*/

define('UPDATE_FILE_DATE', true);

/*
the standard command for ExifTool
overwrites downloaded photos and does
not create a backup copy
*/

define('EXIF_TOOL', PHOTO_DIR.'exiftool -overwrite_original_in_place ');

/*
if set to true
ExifTool ignores minor errors
*/

define('IGNORE_MINOR_EXIF_ERRORS', true);

/*
if set to true
FlickrMovr tries to repair
broken EXIF tags with ExifTool
http://www.sno.phy.queensu.ca/~phil/exiftool/faq.html
*/

define('CORRECT_BROKEN_EXIF_TAGS', false);

/*
enable logging
*/

define('SHOW_LOG_ON_SCREEN', true);

define('WRITE_LOG_TO_FILE', true);

/*
the path and filename of your log-file
*/

define('LOG_FILE', PHOTO_DIR.'flickrmovr.log');

/*
overrides php timeout-limit
0=no time limit

http://php.net/manual/en/function.set-time-limit.php
*/

set_time_limit(0);
