<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:template name="photo">

		<xsl:param name="directory" />

		<div class="photo">
		<div class="thumbnail">

		<a><xsl:attribute name="href">
			<xsl:text>./</xsl:text>
			<xsl:value-of select="$directory" />
			<xsl:text>/</xsl:text>
			<xsl:value-of select="substring(@xml:id,7)" />
			<xsl:text>.jpg</xsl:text>
		</xsl:attribute>

		<img width="75px" height="75px" src="./thumbnail.jpg">
    		<xsl:attribute name="id">
			<xsl:text>img_</xsl:text>
			<xsl:value-of select="substring(@xml:id,7)" />
		</xsl:attribute>
		</img></a>

		</div>

		<div class="meta">

		Title: <a>
			<xsl:attribute name="href">
				<xsl:text>./</xsl:text>
				<xsl:value-of select="$directory" />
				<xsl:text>/</xsl:text>
				<xsl:value-of select="substring(@xml:id,7)" />
				<xsl:text>.jpg</xsl:text>
			</xsl:attribute>
			<xsl:value-of select="@title"/>
		</a>

		<br /><br />

		Description:
		<xsl:choose>
			<xsl:when test="string(@description)"><em><xsl:value-of select="@description"/></em>
			</xsl:when>
			<xsl:otherwise>
			-
			</xsl:otherwise>
		</xsl:choose>

		<br /><br />

		Tags :<xsl:choose>
		<xsl:when test="tags/tag">
			<xsl:for-each select="tags/tag">
				"<xsl:value-of select="@name"/>" 
			</xsl:for-each>
		</xsl:when>
		<xsl:otherwise>
		-
		</xsl:otherwise>
		</xsl:choose>

		</div>

		<br style="clear:both" />

		<div class="info">

			<div class="dates">

			<ul>
			<li>taken: <xsl:value-of select="@date_taken"/></li>
			<li>last modified: <span class="convert_date"><xsl:value-of select="@last_update"/></span></li>
			</ul>

			</div>

			<div class="links">

			<ul>

				<li>
				<xsl:choose>
					<xsl:when test="string(location/@latitude) and string(location/@longitude)">


					<a target="_blank">
					<xsl:attribute name="href">
						<xsl:text>http://maps.google.com/?q=</xsl:text>
						<xsl:value-of select="location/@latitude" />
						<xsl:text>,</xsl:text>
						<xsl:value-of select="location/@longitude" />
					</xsl:attribute>
					Show location (<xsl:value-of select="location/@latitude"/>, <xsl:value-of select="location/@longitude"/>) on Google maps 
					</a>
					</xsl:when>
					<xsl:otherwise>
					<br />
					</xsl:otherwise>
				</xsl:choose>
				</li>

				<li><a target="_blank">
					<xsl:attribute name="href">
						<xsl:value-of select="@flickr_link" />
					</xsl:attribute>
				Open photo page at flickr
			</a></li>

			</ul>

			</div>

			</div>

			<br style="clear:both" />

		</div>
</xsl:template>

<xsl:template match="/">

<html>

<head>
<title>FlickrMovr</title>

<script type="text/javascript" language="javascript">

	/* <![CDATA[ */

	/*
	returns array of elements
	which have a certain class name
	*/

	function get_elements_by_class_name(node, classname) {

		/*
		prefer built-in function, if available
		*/
		if (node.getElementsByClassName)
			return node.getElementsByClassName(classname);

		/*
		custom function
		by Jonathan Snook
		http://snook.ca/archives/javascript/your_favourite_1
		*/

		else {
			var a = [];
			var re = new RegExp('\\b' + classname + '\\b');
			var els = node.getElementsByTagName("*");

			for(var i=0,j=els.length; i<j; i++)
				if(re.test(els[i].className))
					a.push(els[i]);

			return a;
		}
	}

	/*
	adds a leading zero to numbers of <10
	 1 => 01
	10 => 10
	*/

	function lz(number) {
		if (number<10)
			return "0"+number;
		else
			return number;
	}

	/*
	converts a unix-timestamp to date
	*/

	function convert_timestamp_to_date(timestamp) {
		var date = new Date(timestamp * 1000);

		var hour=lz(date.getHours());
		var minute=lz(date.getMinutes());
		var second=lz(date.getSeconds());

		var day=lz(date.getDate());
		var month=lz(date.getMonth()+1);
		var year=date.getFullYear();

		return year+"-"+month+"-"+day+" "+hour+":"+minute+":"+second;
	}

	/*
	assure open sub-sections
	*/

	function assure_open(set) {
		var me=document.getElementById(set);
		if (me.style.display=="none")
			toggle_visibility(set);
	}

	/*
	toggle visibility of a div
	*/

	function toggle_visibility(set) {
		var me=document.getElementById(set);
		var imgs=me.getElementsByTagName('img');
		var directory=document.getElementById('directory_'+set).value;

		/*
		handle thumbnails
		*/

		for (var i=0;i<imgs.length;i++) {
			if (me.style.display=="none"){
				var id=imgs[i].id.substring(4);
				imgs[i].src = './'+directory+'/thumbnails/'+id+'.jpg';
			}
			else {
				imgs[i].src='./thumbnail.jpg';
			}
		}

		/*
		handle div
		*/

		if (me.style.display=="none"){
			me.style.display="block";
		}
		else {
			me.style.display="none";
		}
	}

	/*
	converts a unix-timestamp
	to a human-readable date in UTC
	*/

	function convert_all_timestamps_to_date() {
		var to_convert=get_elements_by_class_name(document, 'convert_date');
		for (var i=0; i<to_convert.length; i++) {
			if (to_convert[i].firstChild) {
				to_convert[i].firstChild.data=convert_timestamp_to_date(to_convert[i].firstChild.data);
				to_convert[i].style.display="inline";
			}
		}
	}
	
	/* ]]> */

</script>

<style type="text/css">
	body {
		font-family:Verdana,Arial,sans-serif;
		font-size:12px;
		background:#F7F7F7;
		text-align:center;
		color:#3F3F3F;
	}

	a {
		text-decoration:none;
		color:#000;
	}

	a:hover {
		text-decoration:underline;
	}

	ul {
		list-style-type:none;
		padding:0;
		margin:0;
	}

	h1 {
		border:2px #FF0084 solid;
		padding:10px;
	}

	h1 a, h1 a:hover, h1.a:visited, h1.a:active {
		color:#0063DC;
	}

	h2 {
		margin:0;
		padding:0px 0px 10px 0px;
	}

	#page {
		text-align:left;
		margin : 0 auto;
		border: 1px #A1A1A1 solid;
		background: #ffffff;
		padding: 10px;
	}

	#page, #page #header {
		width:700px;
	}

	#page #header .logo, .set .header {
		background:#F3F3F3;
	}

	#page #header .info {
		width:350px;
		float:left;
		text-align:left;
	}

	#page #header .info_right {
		text-align:right;
	}

	.set .header, .photo {
		width:680px;
	}

 	.set .header {
		padding:10px;
		border: 1px #A1A1A1 solid;
	}

	.set .header .description {
		width:460px;
		float:left;
	}

	.set .header .info {
		width:200px;
		float:left;
	}

	.set .header a {
		font-weight:bold;
	}

	.set {
		margin-bottom: 30px;
	}

	.photo {
		padding:10px;
		border:1px #A1A1A1 solid;
		border-top:none;
	}

	.photo .thumbnail {
		text-align:center;
	}

	.photo .thumbnail img {
		border:3px #A1A1A1 solid;
	}

	.photo .info {
		padding-top: 20px;
	}

	.photo .dates, .photo .thumbnail {
		float:left;
		width:260px;
	}

	.photo .links, .photo .meta {
		width:400px;
		float:left;
	}

	#page #footer {
		text-align:center;
		font-size: 8pt;
	}

	span.convert_date {
		display:none;
	}
</style>

</head>

<body onload="convert_all_timestamps_to_date()">

<div id="page">

<div id="header">
	<div class="logo">
		<h1><a target="_blank" href="https://www.bernhard-riedl.com/projects/">FlickrMovr</a> for <a target="_blank">
			<xsl:attribute name="href">
				<xsl:text>https://www.flickr.com/photos/</xsl:text>
				<xsl:apply-templates select="flickrmovr/@user_name"/>
				<xsl:text>/</xsl:text>
			</xsl:attribute>
			<xsl:value-of select="flickrmovr/@user_name"/>
		</a></h1>
	</div>

	<div class="info">
		<ul>
			<li>Number of Sets: <xsl:value-of select="count(flickrmovr/set)" /></li>
			<li>Number of Photos: <xsl:value-of select="count(flickrmovr/set/photo)" /></li>
			<li>Number of Photo-Links: <xsl:value-of select="count(flickrmovr/set/photo_links/photo_link)" /></li>
		</ul>
	</div>

	<div class="info_right">
		<ul>
			<li><br /></li>
			<li>Last download started: <span class="convert_date"><xsl:value-of select="flickrmovr/@last_download_started"/></span></li>
			<li>Last download finished: <span class="convert_date"><xsl:value-of select="flickrmovr/@last_download_finished"/></span></li>
		</ul>
	</div>
</div>

<br style="clear:both" />

<xsl:for-each select="flickrmovr/set">
	<xsl:sort select="@title"/>

	<div class="set">

	<div class="header">
		<h2><a>
			<xsl:attribute name="name">
				<xsl:text>anker_</xsl:text>
				<xsl:apply-templates select="@xml:id"/>
			</xsl:attribute>
		</a>

		<a>
			<xsl:attribute name="href">
				<xsl:text>javascript:toggle_visibility('</xsl:text>
				<xsl:apply-templates select="@xml:id"/>
				<xsl:text>');</xsl:text>
			</xsl:attribute>
			<xsl:value-of select="@title"/>
		</a></h2>

		<div class="info">
			<ul>
				<li>Number of Photos: <xsl:value-of select="count(photo)" /></li>
				<li>Number of Photo-Links: <xsl:value-of select="count(photo_links/photo_link)" /></li>
			</ul>
		</div>

		<div class="description">
			Description:
			<xsl:choose>
				<xsl:when test="string(@description)"><em><xsl:value-of select="@description"/></em>
				</xsl:when>
				<xsl:otherwise>
				-
				</xsl:otherwise>
			</xsl:choose>
		</div>

		<br style="clear:both" />

      </div>

	<xsl:variable name="directory">
		<xsl:value-of select="@directory" />
	</xsl:variable>

	<input type="hidden">
		<xsl:attribute name="id">
			<xsl:text>directory_</xsl:text>
			<xsl:apply-templates select="@xml:id"/>
		</xsl:attribute>
		<xsl:attribute name="value">
			<xsl:value-of select="@directory" />
		</xsl:attribute>
	</input>

	<div class="content" style="display:none">
		<xsl:attribute name="id">
			<xsl:apply-templates select="@xml:id"/>
		</xsl:attribute>

	<xsl:for-each select="photo">

		<xsl:sort select="substring(@date_taken,1,4)"/> <!-- year -->
		<xsl:sort select="substring(@date_taken,6,2)"/> <!-- month -->
		<xsl:sort select="substring(@date_taken,9,2)"/> <!--day   -->
		<xsl:sort select="substring(@date_taken,12,2)"/> <!-- hour   -->
		<xsl:sort select="substring(@date_taken,15,2)"/> <!-- minute   -->
		<xsl:sort select="substring(@date_taken,18,2)"/> <!-- second   -->

		<xsl:call-template name="photo">
			<xsl:with-param name="directory" >
				<xsl:value-of select="$directory" />
			</xsl:with-param>
		</xsl:call-template>

	</xsl:for-each>

	<xsl:for-each select="photo_links/photo_link">
		<xsl:variable name="photo_id">
			<xsl:value-of select="@id" />
		</xsl:variable>

		<xsl:for-each select="/flickrmovr/set">

		<xsl:variable name="set_id">
			<xsl:value-of select="@xml:id" />
		</xsl:variable>

		<xsl:variable name="set_title">
			<xsl:value-of select="@title" />
		</xsl:variable>

		<xsl:for-each select="photo">

			<xsl:choose>
				<xsl:when test="@xml:id=$photo_id">

					<div class="photo"><h3>Belongs also to  set
						<a><xsl:attribute name="href">#anker_<xsl:value-of select="$set_id"/></xsl:attribute><xsl:attribute name="onclick">
							<xsl:text>javascript:assure_open('</xsl:text>
							<xsl:value-of select="$set_id"/>	
							<xsl:text>');</xsl:text>
						</xsl:attribute><xsl:value-of select="$set_title"/></a></h3></div>

					<xsl:call-template name="photo">
						<xsl:with-param name="directory" >
							<xsl:value-of select="$directory" />
						</xsl:with-param>
					</xsl:call-template>

				</xsl:when>
			</xsl:choose>

		</xsl:for-each>

		</xsl:for-each>

	</xsl:for-each>

	</div>

	</div>

</xsl:for-each>

<div id="footer"><a target="_blank" href="https://www.bernhard-riedl.com/projects/">FlickrMovr</a> (c) <a target="_blank" href="https://www.bernhard-riedl.com/">Dr. Bernhard Riedl</a> 2009-2017</div>

</div>

</body>

</html>

</xsl:template>

</xsl:stylesheet>

<!--&copy; Dr. Bernhard Riedl &amp; Veronika Grascher-->